Logo AND Algorithmique Numérique Distribuée

Public GIT Repository
Merge branch 'master' of https://framagit.org/simgrid/simgrid into CRTP
authorFrederic Suter <frederic.suter@cc.in2p3.fr>
Fri, 11 Oct 2019 07:12:06 +0000 (09:12 +0200)
committerFrederic Suter <frederic.suter@cc.in2p3.fr>
Fri, 11 Oct 2019 07:12:06 +0000 (09:12 +0200)
.travis.yml
CMakeLists.txt
ChangeLog
NEWS
doc/Doxyfile.in
docs/source/Doxyfile
docs/source/conf.py
include/xbt/base.h
setup.py
sonar-project.properties
src/bindings/java/org/simgrid/NativeLib.java

index ebe6fc1..544b719 100644 (file)
@@ -64,7 +64,7 @@ jobs:
       -  du -hs /tmp || true
       -  ctest --output-on-failure -R java
       -  df -h
-      -  du -hs /tmp || true
+      -  du -hc /tmp || true
 #      -  mingw32-make.exe VERBOSE=1 java-all && ctest --output-on-failure -R java
     - os: osx
       osx_image: xcode11
index eb44314..398bef8 100644 (file)
@@ -95,7 +95,7 @@ endif()
 
 set(SIMGRID_VERSION_MAJOR "3")
 set(SIMGRID_VERSION_MINOR "24")
-set(SIMGRID_VERSION_PATCH "0") # odd => git branch; even => stable release or released snapshot
+set(SIMGRID_VERSION_PATCH "1") # odd => git branch; even => stable release or released snapshot
 
 set(SIMGRID_VERSION_DATE  "2019") # Year for copyright information
 
index ca548e7..b5942a0 100644 (file)
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,9 @@
 ----------------------------------------------------------------------------
 
+SimGrid (3.24.1) NOT RELEASED YET (v3.25 expected December 22. 2029, 04:19 UTC)
+
+----------------------------------------------------------------------------
+
 SimGrid (3.24) October 9. 2019
 
 The Clean Disk Release.
diff --git a/NEWS b/NEWS
index 23ac2ae..c71262e 100644 (file)
--- a/NEWS
+++ b/NEWS
@@ -1,3 +1,10 @@
+                    _               _____  ____  ____
+__   _____ _ __ ___(_) ___  _ __   |___ / |___ \| ___|
+\ \ / / _ \ '__/ __| |/ _ \| '_ \    |_ \   __) |___ \
+ \ V /  __/ |  \__ \ | (_) | | | |  ___) | / __/ ___) |
+  \_/ \___|_|  |___/_|\___/|_| |_| |____(_)_____|____/
+               (not released yet)
+
                     _               _____  ____  _  _
 __   _____ _ __ ___(_) ___  _ __   |___ / |___ \| || |
 \ \ / / _ \ '__/ __| |/ _ \| '_ \    |_ \   __) | || |_
index b641cb4..328c001 100644 (file)
@@ -1443,7 +1443,8 @@ PREDEFINED             = __cplusplus \
                         XBT_ATTRIB_NORETURN= \
                         XBT_ATTRIB_UNUSED= \
                          XBT_ATTRIB_DEPRECATED_v325(m)= \
-                         XBT_ATTRIB_DEPRECATED_v327(m)=
+                         XBT_ATTRIB_DEPRECATED_v327(m)= \
+                         XBT_ATTRIB_DEPRECATED_v328(m)=
 
 # If the MACRO_EXPANSION and EXPAND_ONLY_PREDEF tags are set to YES then
 # this tag can be used to specify a list of macro names that should be expanded.
index 22cefd9..c6235c9 100644 (file)
@@ -42,4 +42,5 @@ PREDEFINED             += \
     XBT_ATTRIB_NORETURN= \
     XBT_ATTRIB_UNUSED= \
     XBT_ATTRIB_DEPRECATED_v325(m)= \
-    XBT_ATTRIB_DEPRECATED_v327(m)=
+    XBT_ATTRIB_DEPRECATED_v327(m)= \
+    XBT_ATTRIB_DEPRECATED_v328(m)=
index 019cb17..a3cf000 100644 (file)
@@ -36,7 +36,7 @@ copyright = u'2002-2019, The SimGrid Team'
 author = u'The SimGrid Team'
 
 # The short X.Y version
-version = u'3.24'
+version = u'3.24.1'
 
 # -- General configuration ---------------------------------------------------
 
index 1f49c1b..871deba 100644 (file)
@@ -72,6 +72,8 @@
   XBT_ATTRIB_DEPRECATED(mesg " (this compatibility wrapper will be dropped in v3.25)") /* Will be dropped in v3.25 */
 #define XBT_ATTRIB_DEPRECATED_v327(mesg)                                                                               \
   XBT_ATTRIB_DEPRECATED(mesg " (this compatibility wrapper will be dropped in v3.27)") /* Will be dropped in v3.27 */
+#define XBT_ATTRIB_DEPRECATED_v328(mesg)                                                                               \
+  XBT_ATTRIB_DEPRECATED(mesg " (this compatibility wrapper will be dropped in v3.28)") /* Will be dropped in v3.28 */
 
 #if !defined(__APPLE__)
 #  define XBT_ATTRIB_CONSTRUCTOR(prio) __attribute__((__constructor__(prio)))
index 55ebf64..bd48de0 100755 (executable)
--- a/setup.py
+++ b/setup.py
@@ -82,7 +82,7 @@ class CMakeBuild(build_ext):
 
 setup(
     name='simgrid',
-    version='3.24',
+    version='3.24.1',
     author='Da SimGrid Team',
     author_email='simgrid-devel@lists.gforge.inria.fr',
     description='Toolkit for scalable simulation of distributed applications',
index 2ff2345..b1ac57c 100644 (file)
@@ -4,7 +4,7 @@
 sonar.organization=simgrid
 sonar.projectKey=simgrid_simgrid
 sonar.projectName=SimGrid
-sonar.projectVersion=3.24
+sonar.projectVersion=3.24.1
 
 sonar.links.homepage=https://simgrid.org
 sonar.links.issue=https://framagit.org/simgrid/simgrid/issues
index a338cc3..5565b1b 100644 (file)
@@ -165,10 +165,10 @@ public final class NativeLib {
                         try (Stream<Path> paths = Files.walk(dir.toPath())) {
                                 paths.sorted(java.util.Comparator.reverseOrder())
                                      .map(java.nio.file.Path::toFile)
//.peek(System.out::println) // Prints what gets removed
                                      .forEach(java.io.File::delete);
                        } catch(Exception e) {
-                               System.out.println("Error while cleaning temporary file "+dir.getAbsolutePath()+" during shutdown: "+e.getCause());
+                               System.err.println("Error while cleaning temporary file "+dir.getAbsolutePath()+" during shutdown: "+e.getCause());
                                e.printStackTrace();
                         }
                }
@@ -165,10 +165,10 @@ public final class NativeLib {
                                 paths.sorted(java.util.Comparator.reverseOrder())
                                      .map(java.nio.file.Path::toFile)
-                                     //.peek(System.out::println) // Prints what gets removed
+                                     //.peek(System.err::println) // Prints what gets removed
                                      .forEach(java.io.File::delete);
                        } catch(Exception e) {